"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ts_simple_ast_1 = __importDefault(require("ts-simple-ast"));
const fs_1 = require("fs");
function printHelp(options) {
    options.format = options.format || 'markdown';
    const isMd = options.format === 'markdown';
    const quote = isMd ? '`' : '';
    const prefix = options.format === 'javascriptString' ? 'const helpText = `' : options.format === 'javascriptStringNoVar' ? '`' : ``;
    const postfix = ['javascriptString', 'javascriptStringNoVar'].includes(options.format) ? '`' : ``;
    const node = getNode(options);
    let s = `${prefix}${printJsDoc(node.getJsDocs())}
 * ${node.getProperties().map(p => quote + p.getName() + quote + ' (' + quote + p.getTypeNode().getText() + quote + '): ' +
        (p.hasQuestionToken() ? 'optional' : 'mandatory') + ' - ' + printJsDoc(p.getJsDocs())).join('\n * ')}
${postfix}`;
    return s;
}
exports.printHelp = printHelp;
function printJsDoc(jsdocs) {
    return jsdocs.map(j => j.getInnerText().replace(/`/gim, '\\`')).join('\n');
}
function getNode(options) {
    const project = new ts_simple_ast_1.default({ useVirtualFileSystem: true });
    const sourceFile = project.createSourceFile('sample.ts', fs_1.readFileSync(options.input).toString());
    try {
        return sourceFile.getInterfaceOrThrow(options.interfaceName);
    }
    catch (error) {
        console.error('Error while getting interface from input files, are you sure interface exists?');
        throw error;
    }
}
//# sourceMappingURL=index.js.map